BroadwayDashboard (BroadwayDashboard v0.2.0) View Source
BroadwayDashboard is a tool to analyze Broadway
pipelines. It provides some insights about performance and errors for
your running pipelines.
It works as an additional page for the Phoenix LiveDashboard.
You can inspect pipelines on remote nodes that are not running BroadwayDashboard too.
See Distribution for details.

Integration with Phoenix LiveDashboard
You can add this page to your Phoenix LiveDashboard by adding as a page in
the live_dashboard macro at your router file.
live_dashboard "/dashboard",
additional_pages: [
broadway: {BroadwayDashboard, pipelines: [MyBroadway]}
]The :pipelines option accept pipeline names (the :name option of your Broadway).
By omitting the :pipelines option, BroadwayDashboard will try to autodiscover your pipelines.
live_dashboard "/dashboard",
additional_pages: [
broadway: BroadwayDashboard
]Once configured, you will be able to access the BroadwayDashboard at /dashboard/broadway.
Distribution
Phoenix LiveDashboard works with distribution out of the box, and it's not different with Broadway Dashboard! You can inspect your pipelines that are running on connected nodes.
You can also inspect pipelines from nodes that are not running the same system of
your dashboard. This is possible because we "copy" the essential parts of this
tool to the remote node when it's not running BroadwayDashboard. We stop the tracking
once the node that started it is disconnected.